import{f as n,a as h,m as b,k as d,c as v}from"./transition-BAtvBeuS.js";import{l as f,p as c,N as u,m as t,A as g,b as x}from"./index-Cp3-A7ao.js";const T=c({fixedHeader:Boolean,fixedFooter:Boolean,height:[Number,String],hover:Boolean,...v(),...d(),...b(),...g()},"VTable"),V=f()({name:"VTable",props:T(),setup(a,r){let{slots:e,emit:y}=r;const{themeClasses:i}=u(a),{densityClasses:m}=n(a);return h(()=>t(a.tag,{class:["v-table",{"v-table--fixed-height":!!a.height,"v-table--fixed-header":a.fixedHeader,"v-table--fixed-footer":a.fixedFooter,"v-table--has-top":!!e.top,"v-table--has-bottom":!!e.bottom,"v-table--hover":a.hover},i.value,m.value,a.class],style:a.style},{default:()=>{var o,l,s;return[(o=e.top)==null?void 0:o.call(e),e.default?t("div",{class:"v-table__wrapper",style:{height:x(a.height)}},[t("table",null,[e.default()])]):(l=e.wrapper)==null?void 0:l.call(e),(s=e.bottom)==null?void 0:s.call(e)]}})),{}}});export{V};
