if(!self.define){let s,e={};const l=(l,r)=>(l=new URL(l+".js",r).href,e[l]||new Promise((e=>{if("document"in self){const s=document.createElement("script");s.src=l,s.onload=e,document.head.appendChild(s)}else s=l,importScripts(l),e()})).then((()=>{let s=e[l];if(!s)throw new Error(`Module ${l} didn’t register its module`);return s})));self.define=(r,i)=>{const n=s||("document"in self?document.currentScript.src:"")||location.href;if(e[n])return;let u={};const o=s=>l(s,n),t={module:{uri:n},exports:u,require:o};e[n]=Promise.all(r.map((s=>t[s]||o(s)))).then((s=>(i(...s),u)))}}define(["./workbox-e3490c72"],(function(s){"use strict";self.addEventListener("message",(s=>{s.data&&"SKIP_WAITING"===s.data.type&&self.skipWaiting()})),s.precacheAndRoute([{url:"assets/_plugin-vue_export-helper-DlAUqK2U.js",revision:null},{url:"assets/CoreConfigs-Cd3zD8ZS.css",revision:null},{url:"assets/CoreConfigs-DXQ09-4Z.js",revision:null},{url:"assets/Default-CdJ0MW70.css",revision:null},{url:"assets/Default-D0_L7GY8.js",revision:null},{url:"assets/Devices-DJykCHDA.js",revision:null},{url:"assets/Devices-DuNQmSvP.css",revision:null},{url:"assets/EditDeviceConfig-CrkRzer2.js",revision:null},{url:"assets/Forecast-B0-jZ2eX.js",revision:null},{url:"assets/Forecast-CrUleTXf.js",revision:null},{url:"assets/forwardRefs-o1fhiqtU.js",revision:null},{url:"assets/Home-CIhEcCeY.js",revision:null},{url:"assets/index-B1qzWewv.css",revision:null},{url:"assets/index-CoXvh_-d.js",revision:null},{url:"assets/index-Cp3-A7ao.js",revision:null},{url:"assets/index-DkrqsE6v.js",revision:null},{url:"assets/PowerFlowCard-BtjLerXU.css",revision:null},{url:"assets/PowerFlowCard-jNGeIg9r.js",revision:null},{url:"assets/RawData-CjWB5rLK.js",revision:null},{url:"assets/RawData-CX07mSyj.css",revision:null},{url:"assets/resizeObserver-BoHHG32A.js",revision:null},{url:"assets/scopeId-BFshC2jm.js",revision:null},{url:"assets/SessionLog-Cs3H4-bi.js",revision:null},{url:"assets/SessionLog-kWkqI-Zp.css",revision:null},{url:"assets/Settings-B1KPEHdJ.js",revision:null},{url:"assets/Statistics-BfmTbYFx.js",revision:null},{url:"assets/transition-BAtvBeuS.js",revision:null},{url:"assets/transition-BWduzWZe.css",revision:null},{url:"assets/utils-D98hIld_.js",revision:null},{url:"assets/VBtn-BqCBlN14.css",revision:null},{url:"assets/VBtn-DJBHxlTa.js",revision:null},{url:"assets/VCard-ByFKzeBx.css",revision:null},{url:"assets/VCard-D5wKeDng.js",revision:null},{url:"assets/VImg-BytK0-PA.css",revision:null},{url:"assets/VImg-tOz2PgiP.js",revision:null},{url:"assets/VInput-BeSPz1TH.css",revision:null},{url:"assets/VInput-BVhPJyoq.js",revision:null},{url:"assets/VOverlay-BvbqXTj9.js",revision:null},{url:"assets/VOverlay-ByPiGQaB.css",revision:null},{url:"assets/VProgressCircular-Cr6MFH6I.css",revision:null},{url:"assets/VProgressCircular-DvjORuMu.js",revision:null},{url:"assets/VSelect-BChZRGSN.css",revision:null},{url:"assets/VSelect-CF9-iJpd.js",revision:null},{url:"assets/VSelectionControl-BZ_M5ICT.css",revision:null},{url:"assets/VSelectionControl-Cd3GaTT-.js",revision:null},{url:"assets/VSlideGroup-BrMBqUtb.js",revision:null},{url:"assets/VSlideGroup-v3jzwQ92.css",revision:null},{url:"assets/VTable-BcHkeDVE.css",revision:null},{url:"assets/VTable-MDvxnV4n.js",revision:null},{url:"assets/VTabs-BNyjYrDB.js",revision:null},{url:"assets/VTabs-CXWw_wzF.css",revision:null},{url:"assets/VTextField-D20FHtqI.js",revision:null},{url:"assets/VTextField-DCmfj468.css",revision:null},{url:"assets/VToolbar-DWxZvWve.css",revision:null},{url:"assets/VToolbar-jYZfQvPG.js",revision:null},{url:"assets/workbox-window.prod.es5-B9K5rw8f.js",revision:null},{url:"index.html",revision:"3f34bc63e763414c474b5d05ba49df14"},{url:"apple-touch-icon.png",revision:"ec84610d7d85b67822bcb8a7f5114354"},{url:"pwa-192x192.png",revision:"568e4ca3a35484f7b1cd02882e9e8ac0"},{url:"pwa-512x512.png",revision:"1e5320b35c3f539c43a9132b901bb0e9"},{url:"robots.txt",revision:"f77c87f977e0fcce05a6df46c885a129"},{url:"manifest.webmanifest",revision:"911eb90ebc08b99acb4dad0970acf877"}],{}),s.cleanupOutdatedCaches(),s.registerRoute(new s.NavigationRoute(s.createHandlerBoundToURL("index.html")))}));
