import{B as v,c as f,ay as g,E as _,m as e,G as V,w as t,J as o,V as b,$ as r,n as B,t as c,H as n,I as i,q as x,u as T}from"./index-Cp3-A7ao.js";import{V as h,a as k}from"./VToolbar-jYZfQvPG.js";import{V as w,a as l}from"./VTabs-BNyjYrDB.js";import"./transition-BAtvBeuS.js";import"./index-DkrqsE6v.js";import"./VImg-tOz2PgiP.js";import"./VBtn-DJBHxlTa.js";import"./forwardRefs-o1fhiqtU.js";import"./VProgressCircular-DvjORuMu.js";import"./resizeObserver-BoHHG32A.js";import"./scopeId-BFshC2jm.js";import"./VSlideGroup-BrMBqUtb.js";const j=v({__name:"Settings",setup(y){const u=g(),m=f(()=>{var s,a;return(s=u.currentRoute.value.name)!=null&&s.toString().includes("forecast")?"forecast":(a=u.currentRoute.value.name)!=null&&a.toString().includes("core")?"core":"devices"});return(s,a)=>{const p=B("router-view");return c(),_("div",null,[e(h,{color:"transparent",title:o(b)("bp4")?o(r)("app.settings"):""},{append:t(()=>[e(w,{"model-value":m.value,"align-tabs":"end",height:"100%"},{default:t(()=>[e(l,{value:"devices",to:{name:"devicessettings"}},{default:t(()=>[n(i(o(r)("settings.devices")),1)]),_:1}),e(l,{value:"forecast",to:{name:"forecastsettings"}},{default:t(()=>[n(i(o(r)("settings.forecast")),1)]),_:1}),e(l,{value:"core",to:{name:"coresettings"}},{default:t(()=>[n(i(o(r)("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),e(k),a[0]||(a[0]=V("div",{style:{height:"15px"}},null,-1)),e(p,null,{default:t(({Component:d})=>[(c(),x(T(d)))]),_:1})])}}});export{j as default};
